# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: metrics.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='metrics.proto',
  package='metrics',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\rmetrics.proto\x12\x07metrics\"N\n\rUploadRequest\x12*\n\x07windows\x18\x01 \x03(\x0b\x32\x19.metrics.PredictionWindow\x12\x11\n\tupload_ts\x18\x02 \x01(\x04\"\x10\n\x0eUploadResponse\"p\n\rWindowMessage\x12\x0f\n\x07\x64\x61ta_id\x18\x01 \x01(\t\x12\x11\n\twindow_id\x18\x02 \x01(\t\x12\x10\n\x08model_id\x18\x03 \x01(\t\x12)\n\x06window\x18\x04 \x01(\x0b\x32\x19.metrics.PredictionWindow\"\x93\x01\n\x06Rollup\x12\x11\n\trollup_id\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\x04\x12\x12\n\nresolution\x18\x03 \x01(\x04\x12\x13\n\x0btime_bucket\x18\x04 \x01(\x04\x12\x11\n\texpire_at\x18\x05 \x01(\x04\x12)\n\x06window\x18\x06 \x01(\x0b\x32\x19.metrics.PredictionWindow\"\xff\x01\n\x10PredictionWindow\x12%\n\x05model\x18\x02 \x01(\x0b\x32\x16.metrics.DeployedModel\x12\x17\n\x0fnum_predictions\x18\x03 \x01(\x04\x12\x10\n\x08start_ts\x18\x04 \x01(\x04\x12\x0e\n\x06\x65nd_ts\x18\x05 \x01(\x04\x12@\n\x0c\x64\x61ta_streams\x18\x06 \x03(\x0b\x32*.metrics.PredictionWindow.DataStreamsEntry\x1aG\n\x10\x44\x61taStreamsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\"\n\x05value\x18\x02 \x01(\x0b\x32\x13.metrics.DataStream:\x02\x38\x01\"\x91\x01\n\rDeployedModel\x12\x17\n\x0f\x64\x65ployment_name\x18\x02 \x01(\t\x12\x36\n\x08metadata\x18\x03 \x03(\x0b\x32$.metrics.DeployedModel.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x9f\x03\n\nDataStream\x12\x33\n\x0b\x64\x61ta_source\x18\x01 \x01(\x0e\x32\x1e.metrics.DataStream.DataSource\x12/\n\tdata_type\x18\x02 \x01(\x0e\x32\x1c.metrics.DataStream.DataType\x12\x31\n\x07metrics\x18\x03 \x03(\x0b\x32 .metrics.DataStream.MetricsEntry\x1a\x43\n\x0cMetricsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\"\n\x05value\x18\x02 \x01(\x0b\x32\x13.metrics.DataMetric:\x02\x38\x01\"\\\n\nDataSource\x12\x13\n\x0fNOT_INITIALIZED\x10\x00\x12\x0f\n\x0bMODEL_INPUT\x10\x01\x12\x10\n\x0cMODEL_OUTPUT\x10\x02\x12\x16\n\x12\x46\x45\x41TURE_IMPORTANCE\x10\x03\"U\n\x08\x44\x61taType\x12\x11\n\rNOT_SPECIFIED\x10\x00\x12\x0b\n\x07TABULAR\x10\x01\x12\t\n\x05IMAGE\x10\x02\x12\x08\n\x04TEXT\x10\x03\x12\t\n\x05\x41UDIO\x10\x04\x12\t\n\x05VIDEO\x10\x05\"\xdd\x03\n\nDataMetric\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x37\n\ndimensions\x18\x02 \x03(\x0b\x32#.metrics.DataMetric.DimensionsEntry\x12,\n\x04type\x18\x03 \x01(\x0e\x32\x1e.metrics.DataMetric.MetricType\x12*\n\x0bgauge_value\x18\x04 \x01(\x0b\x32\x13.metrics.GaugeValueH\x00\x12.\n\rcounter_value\x18\x05 \x01(\x0b\x32\x15.metrics.CounterValueH\x00\x12*\n\x0bratio_value\x18\x06 \x01(\x0b\x32\x13.metrics.RatioValueH\x00\x12\x38\n\x12\x64istribution_value\x18\x07 \x01(\x0b\x32\x1a.metrics.DistributionValueH\x00\x1a\x31\n\x0f\x44imensionsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"V\n\nMetricType\x12\x13\n\x0fNOT_INITIALIZED\x10\x00\x12\t\n\x05GAUGE\x10\x01\x12\x0b\n\x07\x43OUNTER\x10\x02\x12\t\n\x05RATIO\x10\x03\x12\x10\n\x0c\x44ISTRIBUTION\x10\x04\x42\r\n\x0bvalue_oneof\"\x1b\n\nGaugeValue\x12\r\n\x05gauge\x18\x01 \x01(\x01\"\x1f\n\x0c\x43ounterValue\x12\x0f\n\x07\x63ounter\x18\x01 \x01(\x01\",\n\nRatioValue\x12\x0f\n\x07\x63ounter\x18\x01 \x01(\x01\x12\r\n\x05total\x18\x02 \x01(\x01\"\xba\x01\n\x11\x44istributionValue\x12:\n\x0bsketch_impl\x18\x01 \x01(\x0e\x32%.metrics.DistributionValue.SketchImpl\x12,\n\x0csketch_kll10\x18\x02 \x01(\x0b\x32\x14.metrics.SketchKLL10H\x00\"*\n\nSketchImpl\x12\x11\n\rNOT_SPECIFIED\x10\x00\x12\t\n\x05KLL10\x10\x01\x42\x0f\n\rone_of_sketch\"\xa4\x02\n\x0bSketchKLL10\x12\t\n\x01k\x18\x01 \x01(\x04\x12\t\n\x01\x63\x18\x02 \x01(\x01\x12\t\n\x01H\x18\x03 \x01(\x04\x12\x0c\n\x04size\x18\x04 \x01(\x04\x12\x10\n\x08max_size\x18\x05 \x01(\x04\x12\x30\n\titem_type\x18\x06 \x01(\x0e\x32\x1d.metrics.SketchKLL10.ItemType\x12>\n\x11\x63ompactors_double\x18\x07 \x03(\x0b\x32#.metrics.SketchKLL10CompactorDouble\x12>\n\x11\x63ompactors_string\x18\x08 \x03(\x0b\x32#.metrics.SketchKLL10CompactorString\"\"\n\x08ItemType\x12\n\n\x06\x44OUBLE\x10\x00\x12\n\n\x06STRING\x10\x01\"+\n\x1aSketchKLL10CompactorDouble\x12\r\n\x05items\x18\x01 \x03(\x01\"+\n\x1aSketchKLL10CompactorString\x12\r\n\x05items\x18\x01 \x03(\tb\x06proto3'
)



_DATASTREAM_DATASOURCE = _descriptor.EnumDescriptor(
  name='DataSource',
  full_name='metrics.DataStream.DataSource',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NOT_INITIALIZED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MODEL_INPUT', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MODEL_OUTPUT', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FEATURE_IMPORTANCE', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1031,
  serialized_end=1123,
)
_sym_db.RegisterEnumDescriptor(_DATASTREAM_DATASOURCE)

_DATASTREAM_DATATYPE = _descriptor.EnumDescriptor(
  name='DataType',
  full_name='metrics.DataStream.DataType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NOT_SPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TABULAR', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='IMAGE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TEXT', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='AUDIO', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VIDEO', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1125,
  serialized_end=1210,
)
_sym_db.RegisterEnumDescriptor(_DATASTREAM_DATATYPE)

_DATAMETRIC_METRICTYPE = _descriptor.EnumDescriptor(
  name='MetricType',
  full_name='metrics.DataMetric.MetricType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NOT_INITIALIZED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GAUGE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='COUNTER', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RATIO', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DISTRIBUTION', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1589,
  serialized_end=1675,
)
_sym_db.RegisterEnumDescriptor(_DATAMETRIC_METRICTYPE)

_DISTRIBUTIONVALUE_SKETCHIMPL = _descriptor.EnumDescriptor(
  name='SketchImpl',
  full_name='metrics.DistributionValue.SketchImpl',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NOT_SPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='KLL10', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1928,
  serialized_end=1970,
)
_sym_db.RegisterEnumDescriptor(_DISTRIBUTIONVALUE_SKETCHIMPL)

_SKETCHKLL10_ITEMTYPE = _descriptor.EnumDescriptor(
  name='ItemType',
  full_name='metrics.SketchKLL10.ItemType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DOUBLE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STRING', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2248,
  serialized_end=2282,
)
_sym_db.RegisterEnumDescriptor(_SKETCHKLL10_ITEMTYPE)


_UPLOADREQUEST = _descriptor.Descriptor(
  name='UploadRequest',
  full_name='metrics.UploadRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='windows', full_name='metrics.UploadRequest.windows', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='upload_ts', full_name='metrics.UploadRequest.upload_ts', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=26,
  serialized_end=104,
)


_UPLOADRESPONSE = _descriptor.Descriptor(
  name='UploadResponse',
  full_name='metrics.UploadResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=106,
  serialized_end=122,
)


_WINDOWMESSAGE = _descriptor.Descriptor(
  name='WindowMessage',
  full_name='metrics.WindowMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data_id', full_name='metrics.WindowMessage.data_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='window_id', full_name='metrics.WindowMessage.window_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='model_id', full_name='metrics.WindowMessage.model_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='window', full_name='metrics.WindowMessage.window', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=124,
  serialized_end=236,
)


_ROLLUP = _descriptor.Descriptor(
  name='Rollup',
  full_name='metrics.Rollup',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='rollup_id', full_name='metrics.Rollup.rollup_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version', full_name='metrics.Rollup.version', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resolution', full_name='metrics.Rollup.resolution', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_bucket', full_name='metrics.Rollup.time_bucket', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='expire_at', full_name='metrics.Rollup.expire_at', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='window', full_name='metrics.Rollup.window', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=239,
  serialized_end=386,
)


_PREDICTIONWINDOW_DATASTREAMSENTRY = _descriptor.Descriptor(
  name='DataStreamsEntry',
  full_name='metrics.PredictionWindow.DataStreamsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='metrics.PredictionWindow.DataStreamsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='metrics.PredictionWindow.DataStreamsEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=573,
  serialized_end=644,
)

_PREDICTIONWINDOW = _descriptor.Descriptor(
  name='PredictionWindow',
  full_name='metrics.PredictionWindow',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='model', full_name='metrics.PredictionWindow.model', index=0,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='num_predictions', full_name='metrics.PredictionWindow.num_predictions', index=1,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start_ts', full_name='metrics.PredictionWindow.start_ts', index=2,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end_ts', full_name='metrics.PredictionWindow.end_ts', index=3,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data_streams', full_name='metrics.PredictionWindow.data_streams', index=4,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PREDICTIONWINDOW_DATASTREAMSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=389,
  serialized_end=644,
)


_DEPLOYEDMODEL_METADATAENTRY = _descriptor.Descriptor(
  name='MetadataEntry',
  full_name='metrics.DeployedModel.MetadataEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='metrics.DeployedModel.MetadataEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='metrics.DeployedModel.MetadataEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=745,
  serialized_end=792,
)

_DEPLOYEDMODEL = _descriptor.Descriptor(
  name='DeployedModel',
  full_name='metrics.DeployedModel',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='deployment_name', full_name='metrics.DeployedModel.deployment_name', index=0,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='metrics.DeployedModel.metadata', index=1,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_DEPLOYEDMODEL_METADATAENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=647,
  serialized_end=792,
)


_DATASTREAM_METRICSENTRY = _descriptor.Descriptor(
  name='MetricsEntry',
  full_name='metrics.DataStream.MetricsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='metrics.DataStream.MetricsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='metrics.DataStream.MetricsEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=962,
  serialized_end=1029,
)

_DATASTREAM = _descriptor.Descriptor(
  name='DataStream',
  full_name='metrics.DataStream',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data_source', full_name='metrics.DataStream.data_source', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data_type', full_name='metrics.DataStream.data_type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metrics', full_name='metrics.DataStream.metrics', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_DATASTREAM_METRICSENTRY, ],
  enum_types=[
    _DATASTREAM_DATASOURCE,
    _DATASTREAM_DATATYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=795,
  serialized_end=1210,
)


_DATAMETRIC_DIMENSIONSENTRY = _descriptor.Descriptor(
  name='DimensionsEntry',
  full_name='metrics.DataMetric.DimensionsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='metrics.DataMetric.DimensionsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='metrics.DataMetric.DimensionsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1538,
  serialized_end=1587,
)

_DATAMETRIC = _descriptor.Descriptor(
  name='DataMetric',
  full_name='metrics.DataMetric',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='metrics.DataMetric.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dimensions', full_name='metrics.DataMetric.dimensions', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='metrics.DataMetric.type', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gauge_value', full_name='metrics.DataMetric.gauge_value', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='counter_value', full_name='metrics.DataMetric.counter_value', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ratio_value', full_name='metrics.DataMetric.ratio_value', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='distribution_value', full_name='metrics.DataMetric.distribution_value', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_DATAMETRIC_DIMENSIONSENTRY, ],
  enum_types=[
    _DATAMETRIC_METRICTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='value_oneof', full_name='metrics.DataMetric.value_oneof',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1213,
  serialized_end=1690,
)


_GAUGEVALUE = _descriptor.Descriptor(
  name='GaugeValue',
  full_name='metrics.GaugeValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='gauge', full_name='metrics.GaugeValue.gauge', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1692,
  serialized_end=1719,
)


_COUNTERVALUE = _descriptor.Descriptor(
  name='CounterValue',
  full_name='metrics.CounterValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='counter', full_name='metrics.CounterValue.counter', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1721,
  serialized_end=1752,
)


_RATIOVALUE = _descriptor.Descriptor(
  name='RatioValue',
  full_name='metrics.RatioValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='counter', full_name='metrics.RatioValue.counter', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='total', full_name='metrics.RatioValue.total', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1754,
  serialized_end=1798,
)


_DISTRIBUTIONVALUE = _descriptor.Descriptor(
  name='DistributionValue',
  full_name='metrics.DistributionValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sketch_impl', full_name='metrics.DistributionValue.sketch_impl', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sketch_kll10', full_name='metrics.DistributionValue.sketch_kll10', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _DISTRIBUTIONVALUE_SKETCHIMPL,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='one_of_sketch', full_name='metrics.DistributionValue.one_of_sketch',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1801,
  serialized_end=1987,
)


_SKETCHKLL10 = _descriptor.Descriptor(
  name='SketchKLL10',
  full_name='metrics.SketchKLL10',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='k', full_name='metrics.SketchKLL10.k', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='c', full_name='metrics.SketchKLL10.c', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='H', full_name='metrics.SketchKLL10.H', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='size', full_name='metrics.SketchKLL10.size', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_size', full_name='metrics.SketchKLL10.max_size', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='item_type', full_name='metrics.SketchKLL10.item_type', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='compactors_double', full_name='metrics.SketchKLL10.compactors_double', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='compactors_string', full_name='metrics.SketchKLL10.compactors_string', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _SKETCHKLL10_ITEMTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1990,
  serialized_end=2282,
)


_SKETCHKLL10COMPACTORDOUBLE = _descriptor.Descriptor(
  name='SketchKLL10CompactorDouble',
  full_name='metrics.SketchKLL10CompactorDouble',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='metrics.SketchKLL10CompactorDouble.items', index=0,
      number=1, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2284,
  serialized_end=2327,
)


_SKETCHKLL10COMPACTORSTRING = _descriptor.Descriptor(
  name='SketchKLL10CompactorString',
  full_name='metrics.SketchKLL10CompactorString',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='metrics.SketchKLL10CompactorString.items', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2329,
  serialized_end=2372,
)

_UPLOADREQUEST.fields_by_name['windows'].message_type = _PREDICTIONWINDOW
_WINDOWMESSAGE.fields_by_name['window'].message_type = _PREDICTIONWINDOW
_ROLLUP.fields_by_name['window'].message_type = _PREDICTIONWINDOW
_PREDICTIONWINDOW_DATASTREAMSENTRY.fields_by_name['value'].message_type = _DATASTREAM
_PREDICTIONWINDOW_DATASTREAMSENTRY.containing_type = _PREDICTIONWINDOW
_PREDICTIONWINDOW.fields_by_name['model'].message_type = _DEPLOYEDMODEL
_PREDICTIONWINDOW.fields_by_name['data_streams'].message_type = _PREDICTIONWINDOW_DATASTREAMSENTRY
_DEPLOYEDMODEL_METADATAENTRY.containing_type = _DEPLOYEDMODEL
_DEPLOYEDMODEL.fields_by_name['metadata'].message_type = _DEPLOYEDMODEL_METADATAENTRY
_DATASTREAM_METRICSENTRY.fields_by_name['value'].message_type = _DATAMETRIC
_DATASTREAM_METRICSENTRY.containing_type = _DATASTREAM
_DATASTREAM.fields_by_name['data_source'].enum_type = _DATASTREAM_DATASOURCE
_DATASTREAM.fields_by_name['data_type'].enum_type = _DATASTREAM_DATATYPE
_DATASTREAM.fields_by_name['metrics'].message_type = _DATASTREAM_METRICSENTRY
_DATASTREAM_DATASOURCE.containing_type = _DATASTREAM
_DATASTREAM_DATATYPE.containing_type = _DATASTREAM
_DATAMETRIC_DIMENSIONSENTRY.containing_type = _DATAMETRIC
_DATAMETRIC.fields_by_name['dimensions'].message_type = _DATAMETRIC_DIMENSIONSENTRY
_DATAMETRIC.fields_by_name['type'].enum_type = _DATAMETRIC_METRICTYPE
_DATAMETRIC.fields_by_name['gauge_value'].message_type = _GAUGEVALUE
_DATAMETRIC.fields_by_name['counter_value'].message_type = _COUNTERVALUE
_DATAMETRIC.fields_by_name['ratio_value'].message_type = _RATIOVALUE
_DATAMETRIC.fields_by_name['distribution_value'].message_type = _DISTRIBUTIONVALUE
_DATAMETRIC_METRICTYPE.containing_type = _DATAMETRIC
_DATAMETRIC.oneofs_by_name['value_oneof'].fields.append(
  _DATAMETRIC.fields_by_name['gauge_value'])
_DATAMETRIC.fields_by_name['gauge_value'].containing_oneof = _DATAMETRIC.oneofs_by_name['value_oneof']
_DATAMETRIC.oneofs_by_name['value_oneof'].fields.append(
  _DATAMETRIC.fields_by_name['counter_value'])
_DATAMETRIC.fields_by_name['counter_value'].containing_oneof = _DATAMETRIC.oneofs_by_name['value_oneof']
_DATAMETRIC.oneofs_by_name['value_oneof'].fields.append(
  _DATAMETRIC.fields_by_name['ratio_value'])
_DATAMETRIC.fields_by_name['ratio_value'].containing_oneof = _DATAMETRIC.oneofs_by_name['value_oneof']
_DATAMETRIC.oneofs_by_name['value_oneof'].fields.append(
  _DATAMETRIC.fields_by_name['distribution_value'])
_DATAMETRIC.fields_by_name['distribution_value'].containing_oneof = _DATAMETRIC.oneofs_by_name['value_oneof']
_DISTRIBUTIONVALUE.fields_by_name['sketch_impl'].enum_type = _DISTRIBUTIONVALUE_SKETCHIMPL
_DISTRIBUTIONVALUE.fields_by_name['sketch_kll10'].message_type = _SKETCHKLL10
_DISTRIBUTIONVALUE_SKETCHIMPL.containing_type = _DISTRIBUTIONVALUE
_DISTRIBUTIONVALUE.oneofs_by_name['one_of_sketch'].fields.append(
  _DISTRIBUTIONVALUE.fields_by_name['sketch_kll10'])
_DISTRIBUTIONVALUE.fields_by_name['sketch_kll10'].containing_oneof = _DISTRIBUTIONVALUE.oneofs_by_name['one_of_sketch']
_SKETCHKLL10.fields_by_name['item_type'].enum_type = _SKETCHKLL10_ITEMTYPE
_SKETCHKLL10.fields_by_name['compactors_double'].message_type = _SKETCHKLL10COMPACTORDOUBLE
_SKETCHKLL10.fields_by_name['compactors_string'].message_type = _SKETCHKLL10COMPACTORSTRING
_SKETCHKLL10_ITEMTYPE.containing_type = _SKETCHKLL10
DESCRIPTOR.message_types_by_name['UploadRequest'] = _UPLOADREQUEST
DESCRIPTOR.message_types_by_name['UploadResponse'] = _UPLOADRESPONSE
DESCRIPTOR.message_types_by_name['WindowMessage'] = _WINDOWMESSAGE
DESCRIPTOR.message_types_by_name['Rollup'] = _ROLLUP
DESCRIPTOR.message_types_by_name['PredictionWindow'] = _PREDICTIONWINDOW
DESCRIPTOR.message_types_by_name['DeployedModel'] = _DEPLOYEDMODEL
DESCRIPTOR.message_types_by_name['DataStream'] = _DATASTREAM
DESCRIPTOR.message_types_by_name['DataMetric'] = _DATAMETRIC
DESCRIPTOR.message_types_by_name['GaugeValue'] = _GAUGEVALUE
DESCRIPTOR.message_types_by_name['CounterValue'] = _COUNTERVALUE
DESCRIPTOR.message_types_by_name['RatioValue'] = _RATIOVALUE
DESCRIPTOR.message_types_by_name['DistributionValue'] = _DISTRIBUTIONVALUE
DESCRIPTOR.message_types_by_name['SketchKLL10'] = _SKETCHKLL10
DESCRIPTOR.message_types_by_name['SketchKLL10CompactorDouble'] = _SKETCHKLL10COMPACTORDOUBLE
DESCRIPTOR.message_types_by_name['SketchKLL10CompactorString'] = _SKETCHKLL10COMPACTORSTRING
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

UploadRequest = _reflection.GeneratedProtocolMessageType('UploadRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPLOADREQUEST,
  '__module__' : 'metrics_pb2'
  # @@protoc_insertion_point(class_scope:metrics.UploadRequest)
  })
_sym_db.RegisterMessage(UploadRequest)

UploadResponse = _reflection.GeneratedProtocolMessageType('UploadResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPLOADRESPONSE,
  '__module__' : 'metrics_pb2'
  # @@protoc_insertion_point(class_scope:metrics.UploadResponse)
  })
_sym_db.RegisterMessage(UploadResponse)

WindowMessage = _reflection.GeneratedProtocolMessageType('WindowMessage', (_message.Message,), {
  'DESCRIPTOR' : _WINDOWMESSAGE,
  '__module__' : 'metrics_pb2'
  # @@protoc_insertion_point(class_scope:metrics.WindowMessage)
  })
_sym_db.RegisterMessage(WindowMessage)

Rollup = _reflection.GeneratedProtocolMessageType('Rollup', (_message.Message,), {
  'DESCRIPTOR' : _ROLLUP,
  '__module__' : 'metrics_pb2'
  # @@protoc_insertion_point(class_scope:metrics.Rollup)
  })
_sym_db.RegisterMessage(Rollup)

PredictionWindow = _reflection.GeneratedProtocolMessageType('PredictionWindow', (_message.Message,), {

  'DataStreamsEntry' : _reflection.GeneratedProtocolMessageType('DataStreamsEntry', (_message.Message,), {
    'DESCRIPTOR' : _PREDICTIONWINDOW_DATASTREAMSENTRY,
    '__module__' : 'metrics_pb2'
    # @@protoc_insertion_point(class_scope:metrics.PredictionWindow.DataStreamsEntry)
    })
  ,
  'DESCRIPTOR' : _PREDICTIONWINDOW,
  '__module__' : 'metrics_pb2'
  # @@protoc_insertion_point(class_scope:metrics.PredictionWindow)
  })
_sym_db.RegisterMessage(PredictionWindow)
_sym_db.RegisterMessage(PredictionWindow.DataStreamsEntry)

DeployedModel = _reflection.GeneratedProtocolMessageType('DeployedModel', (_message.Message,), {

  'MetadataEntry' : _reflection.GeneratedProtocolMessageType('MetadataEntry', (_message.Message,), {
    'DESCRIPTOR' : _DEPLOYEDMODEL_METADATAENTRY,
    '__module__' : 'metrics_pb2'
    # @@protoc_insertion_point(class_scope:metrics.DeployedModel.MetadataEntry)
    })
  ,
  'DESCRIPTOR' : _DEPLOYEDMODEL,
  '__module__' : 'metrics_pb2'
  # @@protoc_insertion_point(class_scope:metrics.DeployedModel)
  })
_sym_db.RegisterMessage(DeployedModel)
_sym_db.RegisterMessage(DeployedModel.MetadataEntry)

DataStream = _reflection.GeneratedProtocolMessageType('DataStream', (_message.Message,), {

  'MetricsEntry' : _reflection.GeneratedProtocolMessageType('MetricsEntry', (_message.Message,), {
    'DESCRIPTOR' : _DATASTREAM_METRICSENTRY,
    '__module__' : 'metrics_pb2'
    # @@protoc_insertion_point(class_scope:metrics.DataStream.MetricsEntry)
    })
  ,
  'DESCRIPTOR' : _DATASTREAM,
  '__module__' : 'metrics_pb2'
  # @@protoc_insertion_point(class_scope:metrics.DataStream)
  })
_sym_db.RegisterMessage(DataStream)
_sym_db.RegisterMessage(DataStream.MetricsEntry)

DataMetric = _reflection.GeneratedProtocolMessageType('DataMetric', (_message.Message,), {

  'DimensionsEntry' : _reflection.GeneratedProtocolMessageType('DimensionsEntry', (_message.Message,), {
    'DESCRIPTOR' : _DATAMETRIC_DIMENSIONSENTRY,
    '__module__' : 'metrics_pb2'
    # @@protoc_insertion_point(class_scope:metrics.DataMetric.DimensionsEntry)
    })
  ,
  'DESCRIPTOR' : _DATAMETRIC,
  '__module__' : 'metrics_pb2'
  # @@protoc_insertion_point(class_scope:metrics.DataMetric)
  })
_sym_db.RegisterMessage(DataMetric)
_sym_db.RegisterMessage(DataMetric.DimensionsEntry)

GaugeValue = _reflection.GeneratedProtocolMessageType('GaugeValue', (_message.Message,), {
  'DESCRIPTOR' : _GAUGEVALUE,
  '__module__' : 'metrics_pb2'
  # @@protoc_insertion_point(class_scope:metrics.GaugeValue)
  })
_sym_db.RegisterMessage(GaugeValue)

CounterValue = _reflection.GeneratedProtocolMessageType('CounterValue', (_message.Message,), {
  'DESCRIPTOR' : _COUNTERVALUE,
  '__module__' : 'metrics_pb2'
  # @@protoc_insertion_point(class_scope:metrics.CounterValue)
  })
_sym_db.RegisterMessage(CounterValue)

RatioValue = _reflection.GeneratedProtocolMessageType('RatioValue', (_message.Message,), {
  'DESCRIPTOR' : _RATIOVALUE,
  '__module__' : 'metrics_pb2'
  # @@protoc_insertion_point(class_scope:metrics.RatioValue)
  })
_sym_db.RegisterMessage(RatioValue)

DistributionValue = _reflection.GeneratedProtocolMessageType('DistributionValue', (_message.Message,), {
  'DESCRIPTOR' : _DISTRIBUTIONVALUE,
  '__module__' : 'metrics_pb2'
  # @@protoc_insertion_point(class_scope:metrics.DistributionValue)
  })
_sym_db.RegisterMessage(DistributionValue)

SketchKLL10 = _reflection.GeneratedProtocolMessageType('SketchKLL10', (_message.Message,), {
  'DESCRIPTOR' : _SKETCHKLL10,
  '__module__' : 'metrics_pb2'
  # @@protoc_insertion_point(class_scope:metrics.SketchKLL10)
  })
_sym_db.RegisterMessage(SketchKLL10)

SketchKLL10CompactorDouble = _reflection.GeneratedProtocolMessageType('SketchKLL10CompactorDouble', (_message.Message,), {
  'DESCRIPTOR' : _SKETCHKLL10COMPACTORDOUBLE,
  '__module__' : 'metrics_pb2'
  # @@protoc_insertion_point(class_scope:metrics.SketchKLL10CompactorDouble)
  })
_sym_db.RegisterMessage(SketchKLL10CompactorDouble)

SketchKLL10CompactorString = _reflection.GeneratedProtocolMessageType('SketchKLL10CompactorString', (_message.Message,), {
  'DESCRIPTOR' : _SKETCHKLL10COMPACTORSTRING,
  '__module__' : 'metrics_pb2'
  # @@protoc_insertion_point(class_scope:metrics.SketchKLL10CompactorString)
  })
_sym_db.RegisterMessage(SketchKLL10CompactorString)


_PREDICTIONWINDOW_DATASTREAMSENTRY._options = None
_DEPLOYEDMODEL_METADATAENTRY._options = None
_DATASTREAM_METRICSENTRY._options = None
_DATAMETRIC_DIMENSIONSENTRY._options = None
# @@protoc_insertion_point(module_scope)
